# $Id: install.py 1775 2017-12-02 20:13:50Z mwall $
# installer for WeatherLink driver
# Copyright 2014 Matthew Wall

from setup import ExtensionInstaller

def loader():
    return WeatherLinkInstaller()

class WeatherLinkInstaller(ExtensionInstaller):
    def __init__(self):
        super(WeatherLinkInstaller, self).__init__(
            version="0.12",
            name='wlink',
            description='driver that collects data from weatherlink.com',
            author="Matthew Wall",
            author_email="mwall@users.sourceforge.net",
            files=[('bin/user', ['bin/user/wlink.py'])]
            )
